/* @copyright Itential, LLC 2019 (pre-modifications) */

// Set globals
/* global describe it log pronghornProps */
/* eslint global-require: warn */
/* eslint no-unused-vars: warn */
/* eslint import/no-dynamic-require:warn */

// include required items for testing & logging
const assert = require('assert');
const path = require('path');
const util = require('util');
const execute = require('child_process').execSync;
const fs = require('fs-extra');
const mocha = require('mocha');
const winston = require('winston');
const { expect } = require('chai');
const { use } = require('chai');
const td = require('testdouble');
const Ajv = require('ajv');

const ajv = new Ajv({ strictSchema: false, allErrors: true, allowUnionTypes: true });
const anything = td.matchers.anything();
let logLevel = 'none';
const isRapidFail = false;

// read in the properties from the sampleProperties files
let adaptdir = __dirname;
if (adaptdir.endsWith('/test/integration')) {
  adaptdir = adaptdir.substring(0, adaptdir.length - 17);
} else if (adaptdir.endsWith('/test/unit')) {
  adaptdir = adaptdir.substring(0, adaptdir.length - 10);
}
const samProps = require(`${adaptdir}/sampleProperties.json`).properties;

// these variables can be changed to run in integrated mode so easier to set them here
// always check these in with bogus data!!!
samProps.stub = true;
samProps.host = 'replace.hostorip.here';
samProps.authentication.username = 'username';
samProps.authentication.password = 'password';
samProps.protocol = 'http';
samProps.port = 80;
samProps.ssl.enabled = false;
samProps.ssl.accept_invalid_cert = false;
samProps.request.attempt_timeout = 1200000;
const attemptTimeout = samProps.request.attempt_timeout;
const { stub } = samProps;

// these are the adapter properties. You generally should not need to alter
// any of these after they are initially set up
global.pronghornProps = {
  pathProps: {
    encrypted: false
  },
  adapterProps: {
    adapters: [{
      id: 'Test-github',
      type: 'GitHub',
      properties: samProps
    }]
  }
};

global.$HOME = `${__dirname}/../..`;

// set the log levels that Pronghorn uses, spam and trace are not defaulted in so without
// this you may error on log.trace calls.
const myCustomLevels = {
  levels: {
    spam: 6,
    trace: 5,
    debug: 4,
    info: 3,
    warn: 2,
    error: 1,
    none: 0
  }
};

// need to see if there is a log level passed in
process.argv.forEach((val) => {
  // is there a log level defined to be passed in?
  if (val.indexOf('--LOG') === 0) {
    // get the desired log level
    const inputVal = val.split('=')[1];

    // validate the log level is supported, if so set it
    if (Object.hasOwnProperty.call(myCustomLevels.levels, inputVal)) {
      logLevel = inputVal;
    }
  }
});

// need to set global logging
global.log = winston.createLogger({
  level: logLevel,
  levels: myCustomLevels.levels,
  transports: [
    new winston.transports.Console()
  ]
});

/**
 * Runs the error asserts for the test
 */
function runErrorAsserts(data, error, code, origin, displayStr) {
  assert.equal(null, data);
  assert.notEqual(undefined, error);
  assert.notEqual(null, error);
  assert.notEqual(undefined, error.IAPerror);
  assert.notEqual(null, error.IAPerror);
  assert.notEqual(undefined, error.IAPerror.displayString);
  assert.notEqual(null, error.IAPerror.displayString);
  assert.equal(code, error.icode);
  assert.equal(origin, error.IAPerror.origin);
  assert.equal(displayStr, error.IAPerror.displayString);
}

// require the adapter that we are going to be using
const GitHub = require('../../adapter');

// delete the .DS_Store directory in entities -- otherwise this will cause errors
const dirPath = path.join(__dirname, '../../entities/.DS_Store');
if (fs.existsSync(dirPath)) {
  try {
    fs.removeSync(dirPath);
    console.log('.DS_Store deleted');
  } catch (e) {
    console.log('Error when deleting .DS_Store:', e);
  }
}

// begin the testing - these should be pretty well defined between the describe and the it!
describe('[unit] GitHub Adapter Test', () => {
  describe('GitHub Class Tests', () => {
    const a = new GitHub(
      pronghornProps.adapterProps.adapters[0].id,
      pronghornProps.adapterProps.adapters[0].properties
    );

    if (isRapidFail) {
      const state = {};
      state.passed = true;

      mocha.afterEach(function x() {
        state.passed = state.passed
        && (this.currentTest.state === 'passed');
      });
      mocha.beforeEach(function x() {
        if (!state.passed) {
          return this.currentTest.skip();
        }
        return true;
      });
    }

    describe('#class instance created', () => {
      it('should be a class with properties', (done) => {
        try {
          assert.notEqual(null, a);
          assert.notEqual(undefined, a);
          const checkId = global.pronghornProps.adapterProps.adapters[0].id;
          assert.equal(checkId, a.id);
          assert.notEqual(null, a.allProps);
          const check = global.pronghornProps.adapterProps.adapters[0].properties.healthcheck.type;
          assert.equal(check, a.healthcheckType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('adapterBase.js', () => {
      it('should have an adapterBase.js', (done) => {
        try {
          fs.exists('adapterBase.js', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    let wffunctions = [];
    describe('#iapGetAdapterWorkflowFunctions', () => {
      it('should retrieve workflow functions', (done) => {
        try {
          wffunctions = a.iapGetAdapterWorkflowFunctions([]);

          try {
            assert.notEqual(0, wffunctions.length);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('package.json', () => {
      it('should have a package.json', (done) => {
        try {
          fs.exists('package.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json should be validated', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          // Define the JSON schema for package.json
          const packageJsonSchema = {
            type: 'object',
            properties: {
              name: { type: 'string' },
              version: { type: 'string' }
              // May need to add more properties as needed
            },
            required: ['name', 'version']
          };
          const validate = ajv.compile(packageJsonSchema);
          const isValid = validate(packageDotJson);

          if (isValid === false) {
            log.error('The package.json contains errors');
            assert.equal(true, isValid);
          } else {
            assert.equal(true, isValid);
          }

          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json standard fields should be customized', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(-1, packageDotJson.name.indexOf('github'));
          assert.notEqual(undefined, packageDotJson.version);
          assert.notEqual(null, packageDotJson.version);
          assert.notEqual('', packageDotJson.version);
          assert.notEqual(undefined, packageDotJson.description);
          assert.notEqual(null, packageDotJson.description);
          assert.notEqual('', packageDotJson.description);
          assert.equal('adapter.js', packageDotJson.main);
          assert.notEqual(undefined, packageDotJson.wizardVersion);
          assert.notEqual(null, packageDotJson.wizardVersion);
          assert.notEqual('', packageDotJson.wizardVersion);
          assert.notEqual(undefined, packageDotJson.engineVersion);
          assert.notEqual(null, packageDotJson.engineVersion);
          assert.notEqual('', packageDotJson.engineVersion);
          assert.equal('http', packageDotJson.adapterType);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper scripts should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.scripts);
          assert.notEqual(null, packageDotJson.scripts);
          assert.notEqual('', packageDotJson.scripts);
          assert.equal('node utils/setup.js', packageDotJson.scripts.preinstall);
          assert.equal('node --max_old_space_size=4096 ./node_modules/eslint/bin/eslint.js . --ext .json --ext .js', packageDotJson.scripts.lint);
          assert.equal('node --max_old_space_size=4096 ./node_modules/eslint/bin/eslint.js . --ext .json --ext .js --quiet', packageDotJson.scripts['lint:errors']);
          assert.equal('mocha test/unit/adapterBaseTestUnit.js --LOG=error', packageDotJson.scripts['test:baseunit']);
          assert.equal('mocha test/unit/adapterTestUnit.js --LOG=error', packageDotJson.scripts['test:unit']);
          assert.equal('mocha test/integration/adapterTestIntegration.js --LOG=error', packageDotJson.scripts['test:integration']);
          assert.equal('nyc --reporter html --reporter text mocha --reporter dot test/*', packageDotJson.scripts['test:cover']);
          assert.equal('npm run test:baseunit && npm run test:unit && npm run test:integration', packageDotJson.scripts.test);
          assert.equal('npm publish --registry=https://registry.npmjs.org --access=public', packageDotJson.scripts.deploy);
          assert.equal('npm run deploy', packageDotJson.scripts.build);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper directories should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.repository);
          assert.notEqual(null, packageDotJson.repository);
          assert.notEqual('', packageDotJson.repository);
          assert.equal('git', packageDotJson.repository.type);
          assert.equal('git@gitlab.com:itentialopensource/adapters/', packageDotJson.repository.url.substring(0, 43));
          assert.equal('https://gitlab.com/itentialopensource/adapters/', packageDotJson.homepage.substring(0, 47));
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper dependencies should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.dependencies);
          assert.notEqual(null, packageDotJson.dependencies);
          assert.notEqual('', packageDotJson.dependencies);
          assert.equal('^8.12.0', packageDotJson.dependencies.ajv);
          assert.equal('^1.6.8', packageDotJson.dependencies.axios);
          assert.equal('^11.0.0', packageDotJson.dependencies.commander);
          assert.equal('^11.1.1', packageDotJson.dependencies['fs-extra']);
          assert.equal('^10.3.0', packageDotJson.dependencies.mocha);
          assert.equal('^2.0.1', packageDotJson.dependencies['mocha-param']);
          assert.equal('^15.1.0', packageDotJson.dependencies.nyc);
          assert.equal('^0.4.4', packageDotJson.dependencies.ping);
          assert.equal('^1.4.10', packageDotJson.dependencies['readline-sync']);
          assert.equal('^7.5.3', packageDotJson.dependencies.semver);
          assert.equal('^3.9.0', packageDotJson.dependencies.winston);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('package.json proper dev dependencies should be provided', (done) => {
        try {
          const packageDotJson = require('../../package.json');
          assert.notEqual(undefined, packageDotJson.devDependencies);
          assert.notEqual(null, packageDotJson.devDependencies);
          assert.notEqual('', packageDotJson.devDependencies);
          assert.equal('^4.3.7', packageDotJson.devDependencies.chai);
          assert.equal('^8.44.0', packageDotJson.devDependencies.eslint);
          assert.equal('^15.0.0', packageDotJson.devDependencies['eslint-config-airbnb-base']);
          assert.equal('^2.27.5', packageDotJson.devDependencies['eslint-plugin-import']);
          assert.equal('^3.1.0', packageDotJson.devDependencies['eslint-plugin-json']);
          assert.equal('^3.18.0', packageDotJson.devDependencies.testdouble);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('pronghorn.json', () => {
      it('should have a pronghorn.json', (done) => {
        try {
          fs.exists('pronghorn.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should be customized', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          assert.notEqual(-1, pronghornDotJson.id.indexOf('github'));
          assert.equal('Adapter', pronghornDotJson.type);
          assert.equal('GitHub', pronghornDotJson.export);
          assert.equal('GitHub', pronghornDotJson.title);
          assert.equal('adapter.js', pronghornDotJson.src);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should contain generic adapter methods', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          assert.notEqual(undefined, pronghornDotJson.methods);
          assert.notEqual(null, pronghornDotJson.methods);
          assert.notEqual('', pronghornDotJson.methods);
          assert.equal(true, Array.isArray(pronghornDotJson.methods));
          assert.notEqual(0, pronghornDotJson.methods.length);
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapUpdateAdapterConfiguration'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapSuspendAdapter'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapUnsuspendAdapter'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapGetAdapterQueue'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapFindAdapterPath'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapTroubleshootAdapter'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterHealthcheck'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterConnectivity'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterBasicGet'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapMoveAdapterEntitiesToDB'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapDeactivateTasks'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapActivateTasks'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapPopulateEntityCache'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRetrieveEntitiesCache'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'getDevice'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'getDevicesFiltered'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'isAlive'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'getConfig'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapGetDeviceCount'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapExpandedGenericAdapterRequest'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'genericAdapterRequest'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'genericAdapterRequestNoBasePath'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterLint'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapRunAdapterTests'));
          assert.notEqual(undefined, pronghornDotJson.methods.find((e) => e.name === 'iapGetAdapterInventory'));
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json should only expose workflow functions', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');

          for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
            let found = false;
            let paramissue = false;

            for (let w = 0; w < wffunctions.length; w += 1) {
              if (pronghornDotJson.methods[m].name === wffunctions[w]) {
                found = true;
                const methLine = execute(`grep "  ${wffunctions[w]}(" adapter.js | grep "callback) {"`).toString();
                let wfparams = [];

                if (methLine && methLine.indexOf('(') >= 0 && methLine.indexOf(')') >= 0) {
                  const temp = methLine.substring(methLine.indexOf('(') + 1, methLine.lastIndexOf(')'));
                  wfparams = temp.split(',');

                  for (let t = 0; t < wfparams.length; t += 1) {
                    // remove default value from the parameter name
                    wfparams[t] = wfparams[t].substring(0, wfparams[t].search(/=/) > 0 ? wfparams[t].search(/#|\?|=/) : wfparams[t].length);
                    // remove spaces
                    wfparams[t] = wfparams[t].trim();

                    if (wfparams[t] === 'callback') {
                      wfparams.splice(t, 1);
                    }
                  }
                }

                // if there are inputs defined but not on the method line
                if (wfparams.length === 0 && (pronghornDotJson.methods[m].input
                    && pronghornDotJson.methods[m].input.length > 0)) {
                  paramissue = true;
                } else if (wfparams.length > 0 && (!pronghornDotJson.methods[m].input
                    || pronghornDotJson.methods[m].input.length === 0)) {
                  // if there are no inputs defined but there are on the method line
                  paramissue = true;
                } else {
                  for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                    let pfound = false;
                    for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                      if (pronghornDotJson.methods[m].input[p].name.toUpperCase() === wfparams[wfp].toUpperCase()) {
                        pfound = true;
                      }
                    }

                    if (!pfound) {
                      paramissue = true;
                    }
                  }
                  for (let wfp = 0; wfp < wfparams.length; wfp += 1) {
                    let pfound = false;
                    for (let p = 0; p < pronghornDotJson.methods[m].input.length; p += 1) {
                      if (pronghornDotJson.methods[m].input[p].name.toUpperCase() === wfparams[wfp].toUpperCase()) {
                        pfound = true;
                      }
                    }

                    if (!pfound) {
                      paramissue = true;
                    }
                  }
                }

                break;
              }
            }

            if (!found) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${pronghornDotJson.methods[m].name} not found in workflow functions`);
            }
            if (paramissue) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${pronghornDotJson.methods[m].name} has a parameter mismatch`);
            }
            assert.equal(true, found);
            assert.equal(false, paramissue);
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('pronghorn.json should expose all workflow functions', (done) => {
        try {
          const pronghornDotJson = require('../../pronghorn.json');
          for (let w = 0; w < wffunctions.length; w += 1) {
            let found = false;

            for (let m = 0; m < pronghornDotJson.methods.length; m += 1) {
              if (pronghornDotJson.methods[m].name === wffunctions[w]) {
                found = true;
                break;
              }
            }

            if (!found) {
              // this is the reason to go through both loops - log which ones are not found so
              // they can be worked
              log.error(`${wffunctions[w]} not found in pronghorn.json`);
            }
            assert.equal(true, found);
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
      it('pronghorn.json verify input/output schema objects', (done) => {
        const verifySchema = (methodName, schema) => {
          try {
            ajv.compile(schema);
          } catch (error) {
            const errorMessage = `Invalid schema found in '${methodName}' method.
          Schema => ${JSON.stringify(schema)}.
          Details => ${error.message}`;
            throw new Error(errorMessage);
          }
        };

        try {
          const pronghornDotJson = require('../../pronghorn.json');
          const { methods } = pronghornDotJson;
          for (let i = 0; i < methods.length; i += 1) {
            for (let j = 0; j < methods[i].input.length; j += 1) {
              const inputSchema = methods[i].input[j].schema;
              if (inputSchema) {
                verifySchema(methods[i].name, inputSchema);
              }
            }
            const outputSchema = methods[i].output.schema;
            if (outputSchema) {
              verifySchema(methods[i].name, outputSchema);
            }
          }
          done();
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      });
    });

    describe('propertiesSchema.json', () => {
      it('should have a propertiesSchema.json', (done) => {
        try {
          fs.exists('propertiesSchema.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('propertiesSchema.json should be customized', (done) => {
        try {
          const propertiesDotJson = require('../../propertiesSchema.json');
          assert.equal('adapter-github', propertiesDotJson.$id);
          assert.equal('object', propertiesDotJson.type);
          assert.equal('http://json-schema.org/draft-07/schema#', propertiesDotJson.$schema);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('propertiesSchema.json should contain generic adapter properties', (done) => {
        try {
          const propertiesDotJson = require('../../propertiesSchema.json');
          assert.notEqual(undefined, propertiesDotJson.properties);
          assert.notEqual(null, propertiesDotJson.properties);
          assert.notEqual('', propertiesDotJson.properties);
          assert.equal('string', propertiesDotJson.properties.host.type);
          assert.equal('integer', propertiesDotJson.properties.port.type);
          assert.equal('boolean', propertiesDotJson.properties.stub.type);
          assert.equal('string', propertiesDotJson.properties.protocol.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.authentication);
          assert.notEqual(null, propertiesDotJson.definitions.authentication);
          assert.notEqual('', propertiesDotJson.definitions.authentication);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.auth_method.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.username.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.password.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.token.type);
          assert.equal('integer', propertiesDotJson.definitions.authentication.properties.invalid_token_error.type);
          assert.equal('integer', propertiesDotJson.definitions.authentication.properties.token_timeout.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.token_cache.type);
          assert.equal(true, Array.isArray(propertiesDotJson.definitions.authentication.properties.auth_field.type));
          assert.equal(true, Array.isArray(propertiesDotJson.definitions.authentication.properties.auth_field_format.type));
          assert.equal('boolean', propertiesDotJson.definitions.authentication.properties.auth_logging.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.client_id.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.client_secret.type);
          assert.equal('string', propertiesDotJson.definitions.authentication.properties.grant_type.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.ssl);
          assert.notEqual(null, propertiesDotJson.definitions.ssl);
          assert.notEqual('', propertiesDotJson.definitions.ssl);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.ecdhCurve.type);
          assert.equal('boolean', propertiesDotJson.definitions.ssl.properties.enabled.type);
          assert.equal('boolean', propertiesDotJson.definitions.ssl.properties.accept_invalid_cert.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.ca_file.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.key_file.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.cert_file.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.secure_protocol.type);
          assert.equal('string', propertiesDotJson.definitions.ssl.properties.ciphers.type);
          assert.equal('string', propertiesDotJson.properties.base_path.type);
          assert.equal('string', propertiesDotJson.properties.version.type);
          assert.equal('string', propertiesDotJson.properties.cache_location.type);
          assert.equal('boolean', propertiesDotJson.properties.encode_pathvars.type);
          assert.equal('boolean', propertiesDotJson.properties.encode_queryvars.type);
          assert.equal(true, Array.isArray(propertiesDotJson.properties.save_metric.type));
          assert.notEqual(undefined, propertiesDotJson.definitions);
          assert.notEqual(null, propertiesDotJson.definitions);
          assert.notEqual('', propertiesDotJson.definitions);
          assert.notEqual(undefined, propertiesDotJson.definitions.healthcheck);
          assert.notEqual(null, propertiesDotJson.definitions.healthcheck);
          assert.notEqual('', propertiesDotJson.definitions.healthcheck);
          assert.equal('string', propertiesDotJson.definitions.healthcheck.properties.type.type);
          assert.equal('integer', propertiesDotJson.definitions.healthcheck.properties.frequency.type);
          assert.equal('object', propertiesDotJson.definitions.healthcheck.properties.query_object.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.throttle);
          assert.notEqual(null, propertiesDotJson.definitions.throttle);
          assert.notEqual('', propertiesDotJson.definitions.throttle);
          assert.equal('boolean', propertiesDotJson.definitions.throttle.properties.throttle_enabled.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.number_pronghorns.type);
          assert.equal('string', propertiesDotJson.definitions.throttle.properties.sync_async.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.max_in_queue.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.concurrent_max.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.expire_timeout.type);
          assert.equal('integer', propertiesDotJson.definitions.throttle.properties.avg_runtime.type);
          assert.equal('array', propertiesDotJson.definitions.throttle.properties.priorities.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.request);
          assert.notEqual(null, propertiesDotJson.definitions.request);
          assert.notEqual('', propertiesDotJson.definitions.request);
          assert.equal('integer', propertiesDotJson.definitions.request.properties.number_redirects.type);
          assert.equal('integer', propertiesDotJson.definitions.request.properties.number_retries.type);
          assert.equal(true, Array.isArray(propertiesDotJson.definitions.request.properties.limit_retry_error.type));
          assert.equal('array', propertiesDotJson.definitions.request.properties.failover_codes.type);
          assert.equal('integer', propertiesDotJson.definitions.request.properties.attempt_timeout.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.payload.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.uriOptions.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.addlHeaders.type);
          assert.equal('object', propertiesDotJson.definitions.request.properties.global_request.properties.authData.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.healthcheck_on_timeout.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.return_raw.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.archiving.type);
          assert.equal('boolean', propertiesDotJson.definitions.request.properties.return_request.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.proxy);
          assert.notEqual(null, propertiesDotJson.definitions.proxy);
          assert.notEqual('', propertiesDotJson.definitions.proxy);
          assert.equal('boolean', propertiesDotJson.definitions.proxy.properties.enabled.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.host.type);
          assert.equal('integer', propertiesDotJson.definitions.proxy.properties.port.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.protocol.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.username.type);
          assert.equal('string', propertiesDotJson.definitions.proxy.properties.password.type);
          assert.notEqual(undefined, propertiesDotJson.definitions.mongo);
          assert.notEqual(null, propertiesDotJson.definitions.mongo);
          assert.notEqual('', propertiesDotJson.definitions.mongo);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.host.type);
          assert.equal('integer', propertiesDotJson.definitions.mongo.properties.port.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.database.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.username.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.password.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.replSet.type);
          assert.equal('object', propertiesDotJson.definitions.mongo.properties.db_ssl.type);
          assert.equal('boolean', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.enabled.type);
          assert.equal('boolean', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.accept_invalid_cert.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.ca_file.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.key_file.type);
          assert.equal('string', propertiesDotJson.definitions.mongo.properties.db_ssl.properties.cert_file.type);
          assert.notEqual('', propertiesDotJson.definitions.devicebroker);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getDevice.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getDevicesFiltered.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.isAlive.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getConfig.type);
          assert.equal('array', propertiesDotJson.definitions.devicebroker.properties.getCount.type);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('error.json', () => {
      it('should have an error.json', (done) => {
        try {
          fs.exists('error.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('error.json should have standard adapter errors', (done) => {
        try {
          const errorDotJson = require('../../error.json');
          assert.notEqual(undefined, errorDotJson.errors);
          assert.notEqual(null, errorDotJson.errors);
          assert.notEqual('', errorDotJson.errors);
          assert.equal(true, Array.isArray(errorDotJson.errors));
          assert.notEqual(0, errorDotJson.errors.length);
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.100'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.101'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.102'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.110'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.111'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.112'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.113'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.114'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.115'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.116'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.300'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.301'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.302'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.303'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.304'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.305'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.310'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.311'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.312'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.320'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.321'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.400'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.401'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.402'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.500'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.501'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.502'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.503'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.600'));
          assert.notEqual(undefined, errorDotJson.errors.find((e) => e.icode === 'AD.900'));
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('sampleProperties.json', () => {
      it('should have a sampleProperties.json', (done) => {
        try {
          fs.exists('sampleProperties.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('sampleProperties.json should contain generic adapter properties', (done) => {
        try {
          const sampleDotJson = require('../../sampleProperties.json');
          assert.notEqual(-1, sampleDotJson.id.indexOf('github'));
          assert.equal('GitHub', sampleDotJson.type);
          assert.notEqual(undefined, sampleDotJson.properties);
          assert.notEqual(null, sampleDotJson.properties);
          assert.notEqual('', sampleDotJson.properties);
          assert.notEqual(undefined, sampleDotJson.properties.host);
          assert.notEqual(undefined, sampleDotJson.properties.port);
          assert.notEqual(undefined, sampleDotJson.properties.stub);
          assert.notEqual(undefined, sampleDotJson.properties.protocol);
          assert.notEqual(undefined, sampleDotJson.properties.authentication);
          assert.notEqual(null, sampleDotJson.properties.authentication);
          assert.notEqual('', sampleDotJson.properties.authentication);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_method);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.username);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.password);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.token);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.invalid_token_error);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.token_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.token_cache);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_field);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_field_format);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.auth_logging);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.client_id);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.client_secret);
          assert.notEqual(undefined, sampleDotJson.properties.authentication.grant_type);
          assert.notEqual(undefined, sampleDotJson.properties.ssl);
          assert.notEqual(null, sampleDotJson.properties.ssl);
          assert.notEqual('', sampleDotJson.properties.ssl);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.ecdhCurve);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.enabled);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.accept_invalid_cert);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.ca_file);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.key_file);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.cert_file);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.secure_protocol);
          assert.notEqual(undefined, sampleDotJson.properties.ssl.ciphers);
          assert.notEqual(undefined, sampleDotJson.properties.base_path);
          assert.notEqual(undefined, sampleDotJson.properties.version);
          assert.notEqual(undefined, sampleDotJson.properties.cache_location);
          assert.notEqual(undefined, sampleDotJson.properties.encode_pathvars);
          assert.notEqual(undefined, sampleDotJson.properties.encode_queryvars);
          assert.notEqual(undefined, sampleDotJson.properties.save_metric);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck);
          assert.notEqual(null, sampleDotJson.properties.healthcheck);
          assert.notEqual('', sampleDotJson.properties.healthcheck);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck.type);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck.frequency);
          assert.notEqual(undefined, sampleDotJson.properties.healthcheck.query_object);
          assert.notEqual(undefined, sampleDotJson.properties.throttle);
          assert.notEqual(null, sampleDotJson.properties.throttle);
          assert.notEqual('', sampleDotJson.properties.throttle);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.throttle_enabled);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.number_pronghorns);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.sync_async);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.max_in_queue);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.concurrent_max);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.expire_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.avg_runtime);
          assert.notEqual(undefined, sampleDotJson.properties.throttle.priorities);
          assert.notEqual(undefined, sampleDotJson.properties.request);
          assert.notEqual(null, sampleDotJson.properties.request);
          assert.notEqual('', sampleDotJson.properties.request);
          assert.notEqual(undefined, sampleDotJson.properties.request.number_redirects);
          assert.notEqual(undefined, sampleDotJson.properties.request.number_retries);
          assert.notEqual(undefined, sampleDotJson.properties.request.limit_retry_error);
          assert.notEqual(undefined, sampleDotJson.properties.request.failover_codes);
          assert.notEqual(undefined, sampleDotJson.properties.request.attempt_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.payload);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.uriOptions);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.addlHeaders);
          assert.notEqual(undefined, sampleDotJson.properties.request.global_request.authData);
          assert.notEqual(undefined, sampleDotJson.properties.request.healthcheck_on_timeout);
          assert.notEqual(undefined, sampleDotJson.properties.request.return_raw);
          assert.notEqual(undefined, sampleDotJson.properties.request.archiving);
          assert.notEqual(undefined, sampleDotJson.properties.request.return_request);
          assert.notEqual(undefined, sampleDotJson.properties.proxy);
          assert.notEqual(null, sampleDotJson.properties.proxy);
          assert.notEqual('', sampleDotJson.properties.proxy);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.enabled);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.host);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.port);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.protocol);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.username);
          assert.notEqual(undefined, sampleDotJson.properties.proxy.password);
          assert.notEqual(undefined, sampleDotJson.properties.mongo);
          assert.notEqual(null, sampleDotJson.properties.mongo);
          assert.notEqual('', sampleDotJson.properties.mongo);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.host);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.port);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.database);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.username);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.password);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.replSet);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.enabled);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.accept_invalid_cert);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.ca_file);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.key_file);
          assert.notEqual(undefined, sampleDotJson.properties.mongo.db_ssl.cert_file);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getDevice);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getDevicesFiltered);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.isAlive);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getConfig);
          assert.notEqual(undefined, sampleDotJson.properties.devicebroker.getCount);
          assert.notEqual(undefined, sampleDotJson.properties.cache);
          assert.notEqual(undefined, sampleDotJson.properties.cache.entities);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#checkProperties', () => {
      it('should have a checkProperties function', (done) => {
        try {
          assert.equal(true, typeof a.checkProperties === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('the sample properties should be good - if failure change the log level', (done) => {
        try {
          const samplePropsJson = require('../../sampleProperties.json');
          const clean = a.checkProperties(samplePropsJson.properties);

          try {
            assert.notEqual(0, Object.keys(clean));
            assert.equal(undefined, clean.exception);
            assert.notEqual(undefined, clean.host);
            assert.notEqual(null, clean.host);
            assert.notEqual('', clean.host);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('README.md', () => {
      it('should have a README', (done) => {
        try {
          fs.exists('README.md', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('README.md should be customized', (done) => {
        try {
          fs.readFile('README.md', 'utf8', (err, data) => {
            assert.equal(-1, data.indexOf('[System]'));
            assert.equal(-1, data.indexOf('[system]'));
            assert.equal(-1, data.indexOf('[version]'));
            assert.equal(-1, data.indexOf('[namespace]'));
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#connect', () => {
      it('should have a connect function', (done) => {
        try {
          assert.equal(true, typeof a.connect === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#healthCheck', () => {
      it('should have a healthCheck function', (done) => {
        try {
          assert.equal(true, typeof a.healthCheck === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapUpdateAdapterConfiguration', () => {
      it('should have a iapUpdateAdapterConfiguration function', (done) => {
        try {
          assert.equal(true, typeof a.iapUpdateAdapterConfiguration === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapSuspendAdapter', () => {
      it('should have a iapSuspendAdapter function', (done) => {
        try {
          assert.equal(true, typeof a.iapSuspendAdapter === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapUnsuspendAdapter', () => {
      it('should have a iapUnsuspendAdapter function', (done) => {
        try {
          assert.equal(true, typeof a.iapUnsuspendAdapter === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapGetAdapterQueue', () => {
      it('should have a iapGetAdapterQueue function', (done) => {
        try {
          assert.equal(true, typeof a.iapGetAdapterQueue === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapFindAdapterPath', () => {
      it('should have a iapFindAdapterPath function', (done) => {
        try {
          assert.equal(true, typeof a.iapFindAdapterPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('iapFindAdapterPath should find atleast one path that matches', (done) => {
        try {
          a.iapFindAdapterPath('{base_path}/{version}', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.equal(true, data.found);
              assert.notEqual(undefined, data.foundIn);
              assert.notEqual(null, data.foundIn);
              assert.notEqual(0, data.foundIn.length);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#iapTroubleshootAdapter', () => {
      it('should have a iapTroubleshootAdapter function', (done) => {
        try {
          assert.equal(true, typeof a.iapTroubleshootAdapter === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterHealthcheck', () => {
      it('should have a iapRunAdapterHealthcheck function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterHealthcheck === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterConnectivity', () => {
      it('should have a iapRunAdapterConnectivity function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterConnectivity === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterBasicGet', () => {
      it('should have a iapRunAdapterBasicGet function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterBasicGet === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapMoveAdapterEntitiesToDB', () => {
      it('should have a iapMoveAdapterEntitiesToDB function', (done) => {
        try {
          assert.equal(true, typeof a.iapMoveAdapterEntitiesToDB === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#checkActionFiles', () => {
      it('should have a checkActionFiles function', (done) => {
        try {
          assert.equal(true, typeof a.checkActionFiles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('the action files should be good - if failure change the log level as most issues are warnings', (done) => {
        try {
          const clean = a.checkActionFiles();

          try {
            for (let c = 0; c < clean.length; c += 1) {
              log.error(clean[c]);
            }
            assert.equal(0, clean.length);
            done();
          } catch (err) {
            log.error(`Test Failure: ${err}`);
            done(err);
          }
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#encryptProperty', () => {
      it('should have a encryptProperty function', (done) => {
        try {
          assert.equal(true, typeof a.encryptProperty === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('should get base64 encoded property', (done) => {
        try {
          a.encryptProperty('testing', 'base64', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.response);
              assert.notEqual(null, data.response);
              assert.equal(0, data.response.indexOf('{code}'));
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should get encrypted property', (done) => {
        try {
          a.encryptProperty('testing', 'encrypt', (data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.response);
              assert.notEqual(null, data.response);
              assert.equal(0, data.response.indexOf('{crypt}'));
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#iapDeactivateTasks', () => {
      it('should have a iapDeactivateTasks function', (done) => {
        try {
          assert.equal(true, typeof a.iapDeactivateTasks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapActivateTasks', () => {
      it('should have a iapActivateTasks function', (done) => {
        try {
          assert.equal(true, typeof a.iapActivateTasks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapPopulateEntityCache', () => {
      it('should have a iapPopulateEntityCache function', (done) => {
        try {
          assert.equal(true, typeof a.iapPopulateEntityCache === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRetrieveEntitiesCache', () => {
      it('should have a iapRetrieveEntitiesCache function', (done) => {
        try {
          assert.equal(true, typeof a.iapRetrieveEntitiesCache === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#hasEntities', () => {
      it('should have a hasEntities function', (done) => {
        try {
          assert.equal(true, typeof a.hasEntities === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#getDevice', () => {
      it('should have a getDevice function', (done) => {
        try {
          assert.equal(true, typeof a.getDevice === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#getDevicesFiltered', () => {
      it('should have a getDevicesFiltered function', (done) => {
        try {
          assert.equal(true, typeof a.getDevicesFiltered === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#isAlive', () => {
      it('should have a isAlive function', (done) => {
        try {
          assert.equal(true, typeof a.isAlive === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#getConfig', () => {
      it('should have a getConfig function', (done) => {
        try {
          assert.equal(true, typeof a.getConfig === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapGetDeviceCount', () => {
      it('should have a iapGetDeviceCount function', (done) => {
        try {
          assert.equal(true, typeof a.iapGetDeviceCount === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapExpandedGenericAdapterRequest', () => {
      it('should have a iapExpandedGenericAdapterRequest function', (done) => {
        try {
          assert.equal(true, typeof a.iapExpandedGenericAdapterRequest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#genericAdapterRequest', () => {
      it('should have a genericAdapterRequest function', (done) => {
        try {
          assert.equal(true, typeof a.genericAdapterRequest === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#genericAdapterRequestNoBasePath', () => {
      it('should have a genericAdapterRequestNoBasePath function', (done) => {
        try {
          assert.equal(true, typeof a.genericAdapterRequestNoBasePath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapRunAdapterLint', () => {
      it('should have a iapRunAdapterLint function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterLint === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('retrieve the lint results', (done) => {
        try {
          a.iapRunAdapterLint((data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              assert.notEqual(undefined, data.status);
              assert.notEqual(null, data.status);
              assert.equal('SUCCESS', data.status);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#iapRunAdapterTests', () => {
      it('should have a iapRunAdapterTests function', (done) => {
        try {
          assert.equal(true, typeof a.iapRunAdapterTests === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });

    describe('#iapGetAdapterInventory', () => {
      it('should have a iapGetAdapterInventory function', (done) => {
        try {
          assert.equal(true, typeof a.iapGetAdapterInventory === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('retrieve the inventory', (done) => {
        try {
          a.iapGetAdapterInventory((data, error) => {
            try {
              assert.equal(undefined, error);
              assert.notEqual(undefined, data);
              assert.notEqual(null, data);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });
    describe('metadata.json', () => {
      it('should have a metadata.json', (done) => {
        try {
          fs.exists('metadata.json', (val) => {
            assert.equal(true, val);
            done();
          });
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('metadata.json is customized', (done) => {
        try {
          const metadataDotJson = require('../../metadata.json');
          assert.equal('adapter-github', metadataDotJson.name);
          assert.notEqual(undefined, metadataDotJson.webName);
          assert.notEqual(null, metadataDotJson.webName);
          assert.notEqual('', metadataDotJson.webName);
          assert.equal('Adapter', metadataDotJson.type);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('metadata.json contains accurate documentation', (done) => {
        try {
          const metadataDotJson = require('../../metadata.json');
          assert.notEqual(undefined, metadataDotJson.documentation);
          assert.equal('https://www.npmjs.com/package/@itentialopensource/adapter-github', metadataDotJson.documentation.npmLink);
          assert.equal('https://docs.itential.com/opensource/docs/troubleshooting-an-adapter', metadataDotJson.documentation.faqLink);
          assert.equal('https://gitlab.com/itentialopensource/adapters/contributing-guide', metadataDotJson.documentation.contributeLink);
          assert.equal('https://itential.atlassian.net/servicedesk/customer/portals', metadataDotJson.documentation.issueLink);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
      it('metadata.json has related items', (done) => {
        try {
          const metadataDotJson = require('../../metadata.json');
          assert.notEqual(undefined, metadataDotJson.relatedItems);
          assert.notEqual(undefined, metadataDotJson.relatedItems.adapters);
          assert.notEqual(undefined, metadataDotJson.relatedItems.integrations);
          assert.notEqual(undefined, metadataDotJson.relatedItems.ecosystemApplications);
          assert.notEqual(undefined, metadataDotJson.relatedItems.workflowProjects);
          assert.notEqual(undefined, metadataDotJson.relatedItems.transformationProjects);
          assert.notEqual(undefined, metadataDotJson.relatedItems.exampleProjects);
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      });
    });
    /*
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    *** All code above this comment will be replaced during a migration ***
    ******************* DO NOT REMOVE THIS COMMENT BLOCK ******************
    -----------------------------------------------------------------------
    -----------------------------------------------------------------------
    */

    describe('#getEmojis - errors', () => {
      it('should have a getEmojis function', (done) => {
        try {
          assert.equal(true, typeof a.getEmojis === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getEvents - errors', () => {
      it('should have a getEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getFeeds - errors', () => {
      it('should have a getFeeds function', (done) => {
        try {
          assert.equal(true, typeof a.getFeeds === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGists - errors', () => {
      it('should have a getGists function', (done) => {
        try {
          assert.equal(true, typeof a.getGists === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGists - errors', () => {
      it('should have a postGists function', (done) => {
        try {
          assert.equal(true, typeof a.postGists === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postGists(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGists', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsPublic - errors', () => {
      it('should have a getGistsPublic function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsPublic === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsStarred - errors', () => {
      it('should have a getGistsStarred function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsStarred === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsId - errors', () => {
      it('should have a deleteGistsId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteGistsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteGistsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsId - errors', () => {
      it('should have a getGistsId function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchGistsId - errors', () => {
      it('should have a patchGistsId function', (done) => {
        try {
          assert.equal(true, typeof a.patchGistsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchGistsId(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchGistsId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdComments - errors', () => {
      it('should have a getGistsIdComments function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsIdComments(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGistsIdComments - errors', () => {
      it('should have a postGistsIdComments function', (done) => {
        try {
          assert.equal(true, typeof a.postGistsIdComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.postGistsIdComments(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGistsIdComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postGistsIdComments('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGistsIdComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsIdCommentsCommentId - errors', () => {
      it('should have a deleteGistsIdCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteGistsIdCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteGistsIdCommentsCommentId(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteGistsIdCommentsCommentId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdCommentsCommentId - errors', () => {
      it('should have a getGistsIdCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsIdCommentsCommentId(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getGistsIdCommentsCommentId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchGistsIdCommentsCommentId - errors', () => {
      it('should have a patchGistsIdCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchGistsIdCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchGistsIdCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchGistsIdCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchGistsIdCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchGistsIdCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postGistsIdForks - errors', () => {
      it('should have a postGistsIdForks function', (done) => {
        try {
          assert.equal(true, typeof a.postGistsIdForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.postGistsIdForks(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postGistsIdForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteGistsIdStar - errors', () => {
      it('should have a deleteGistsIdStar function', (done) => {
        try {
          assert.equal(true, typeof a.deleteGistsIdStar === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteGistsIdStar(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteGistsIdStar', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGistsIdStar - errors', () => {
      it('should have a getGistsIdStar function', (done) => {
        try {
          assert.equal(true, typeof a.getGistsIdStar === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getGistsIdStar(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGistsIdStar', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putGistsIdStar - errors', () => {
      it('should have a putGistsIdStar function', (done) => {
        try {
          assert.equal(true, typeof a.putGistsIdStar === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.putGistsIdStar(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putGistsIdStar', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGitignoreTemplates - errors', () => {
      it('should have a getGitignoreTemplates function', (done) => {
        try {
          assert.equal(true, typeof a.getGitignoreTemplates === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getGitignoreTemplatesLanguage - errors', () => {
      it('should have a getGitignoreTemplatesLanguage function', (done) => {
        try {
          assert.equal(true, typeof a.getGitignoreTemplatesLanguage === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing language', (done) => {
        try {
          a.getGitignoreTemplatesLanguage(null, (data, error) => {
            try {
              const displayE = 'language is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getGitignoreTemplatesLanguage', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getIssues - errors', () => {
      it('should have a getIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing filter', (done) => {
        try {
          a.getIssues(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'filter is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getIssues('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing labels', (done) => {
        try {
          a.getIssues('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'labels is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sort', (done) => {
        try {
          a.getIssues('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'sort is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing direction', (done) => {
        try {
          a.getIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'direction is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyIssuesSearchOwnerRepositoryStateKeyword - errors', () => {
      it('should have a getLegacyIssuesSearchOwnerRepositoryStateKeyword function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyIssuesSearchOwnerRepositoryStateKeyword === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyword', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword(null, null, null, null, (data, error) => {
            try {
              const displayE = 'keyword is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repository', (done) => {
        try {
          a.getLegacyIssuesSearchOwnerRepositoryStateKeyword('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repository is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyIssuesSearchOwnerRepositoryStateKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyReposSearchKeyword - errors', () => {
      it('should have a getLegacyReposSearchKeyword function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyReposSearchKeyword === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyword', (done) => {
        try {
          a.getLegacyReposSearchKeyword(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'keyword is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyReposSearchKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyUserEmailEmail - errors', () => {
      it('should have a getLegacyUserEmailEmail function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyUserEmailEmail === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing email', (done) => {
        try {
          a.getLegacyUserEmailEmail(null, (data, error) => {
            try {
              const displayE = 'email is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyUserEmailEmail', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getLegacyUserSearchKeyword - errors', () => {
      it('should have a getLegacyUserSearchKeyword function', (done) => {
        try {
          assert.equal(true, typeof a.getLegacyUserSearchKeyword === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyword', (done) => {
        try {
          a.getLegacyUserSearchKeyword(null, null, null, null, (data, error) => {
            try {
              const displayE = 'keyword is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getLegacyUserSearchKeyword', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postMarkdown - errors', () => {
      it('should have a postMarkdown function', (done) => {
        try {
          assert.equal(true, typeof a.postMarkdown === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postMarkdown(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postMarkdown', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postMarkdownRaw - errors', () => {
      it('should have a postMarkdownRaw function', (done) => {
        try {
          assert.equal(true, typeof a.postMarkdownRaw === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getMeta - errors', () => {
      it('should have a getMeta function', (done) => {
        try {
          assert.equal(true, typeof a.getMeta === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNetworksOwnerRepoEvents - errors', () => {
      it('should have a getNetworksOwnerRepoEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getNetworksOwnerRepoEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getNetworksOwnerRepoEvents(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNetworksOwnerRepoEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getNetworksOwnerRepoEvents('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNetworksOwnerRepoEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotifications - errors', () => {
      it('should have a getNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.getNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putNotifications - errors', () => {
      it('should have a putNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.putNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putNotifications(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsThreadsId - errors', () => {
      it('should have a getNotificationsThreadsId function', (done) => {
        try {
          assert.equal(true, typeof a.getNotificationsThreadsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getNotificationsThreadsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNotificationsThreadsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchNotificationsThreadsId - errors', () => {
      it('should have a patchNotificationsThreadsId function', (done) => {
        try {
          assert.equal(true, typeof a.patchNotificationsThreadsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchNotificationsThreadsId(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchNotificationsThreadsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteNotificationsThreadsIdSubscription - errors', () => {
      it('should have a deleteNotificationsThreadsIdSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.deleteNotificationsThreadsIdSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteNotificationsThreadsIdSubscription(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getNotificationsThreadsIdSubscription - errors', () => {
      it('should have a getNotificationsThreadsIdSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.getNotificationsThreadsIdSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getNotificationsThreadsIdSubscription(null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putNotificationsThreadsIdSubscription - errors', () => {
      it('should have a putNotificationsThreadsIdSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.putNotificationsThreadsIdSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.putNotificationsThreadsIdSubscription(null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putNotificationsThreadsIdSubscription('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putNotificationsThreadsIdSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrg - errors', () => {
      it('should have a getOrgsOrg function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrg(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchOrgsOrg - errors', () => {
      it('should have a patchOrgsOrg function', (done) => {
        try {
          assert.equal(true, typeof a.patchOrgsOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.patchOrgsOrg(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchOrgsOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgEvents - errors', () => {
      it('should have a getOrgsOrgEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgEvents(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgIssues - errors', () => {
      it('should have a getOrgsOrgIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgIssues(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing filter', (done) => {
        try {
          a.getOrgsOrgIssues('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'filter is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getOrgsOrgIssues('fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing labels', (done) => {
        try {
          a.getOrgsOrgIssues('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'labels is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sort', (done) => {
        try {
          a.getOrgsOrgIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'sort is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing direction', (done) => {
        try {
          a.getOrgsOrgIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'direction is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgMembers - errors', () => {
      it('should have a getOrgsOrgMembers function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgMembers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgMembers(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteOrgsOrgMembersUsername - errors', () => {
      it('should have a deleteOrgsOrgMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteOrgsOrgMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.deleteOrgsOrgMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteOrgsOrgMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgMembersUsername - errors', () => {
      it('should have a getOrgsOrgMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getOrgsOrgMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembers - errors', () => {
      it('should have a getOrgsOrgPublicMembers function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgPublicMembers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgPublicMembers(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteOrgsOrgPublicMembersUsername - errors', () => {
      it('should have a deleteOrgsOrgPublicMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteOrgsOrgPublicMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.deleteOrgsOrgPublicMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteOrgsOrgPublicMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgPublicMembersUsername - errors', () => {
      it('should have a getOrgsOrgPublicMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgPublicMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgPublicMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getOrgsOrgPublicMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putOrgsOrgPublicMembersUsername - errors', () => {
      it('should have a putOrgsOrgPublicMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putOrgsOrgPublicMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.putOrgsOrgPublicMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putOrgsOrgPublicMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putOrgsOrgPublicMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgRepos - errors', () => {
      it('should have a getOrgsOrgRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgRepos(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postOrgsOrgRepos - errors', () => {
      it('should have a postOrgsOrgRepos function', (done) => {
        try {
          assert.equal(true, typeof a.postOrgsOrgRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.postOrgsOrgRepos(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postOrgsOrgRepos('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getOrgsOrgTeams - errors', () => {
      it('should have a getOrgsOrgTeams function', (done) => {
        try {
          assert.equal(true, typeof a.getOrgsOrgTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getOrgsOrgTeams(null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getOrgsOrgTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postOrgsOrgTeams - errors', () => {
      it('should have a postOrgsOrgTeams function', (done) => {
        try {
          assert.equal(true, typeof a.postOrgsOrgTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.postOrgsOrgTeams(null, null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postOrgsOrgTeams('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postOrgsOrgTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRateLimit - errors', () => {
      it('should have a getRateLimit function', (done) => {
        try {
          assert.equal(true, typeof a.getRateLimit === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepo - errors', () => {
      it('should have a deleteReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepo - errors', () => {
      it('should have a getReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepo - errors', () => {
      it('should have a patchReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssignees - errors', () => {
      it('should have a getReposOwnerRepoAssignees function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoAssignees === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoAssignees(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoAssignees('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssignees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoAssigneesAssignee - errors', () => {
      it('should have a getReposOwnerRepoAssigneesAssignee function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoAssigneesAssignee === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesAssignee', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesAssignee', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing assignee', (done) => {
        try {
          a.getReposOwnerRepoAssigneesAssignee('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'assignee is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoAssigneesAssignee', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoBranches - errors', () => {
      it('should have a getReposOwnerRepoBranches function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoBranches === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoBranches(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranches', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoBranches('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranches', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoBranchesBranch - errors', () => {
      it('should have a getReposOwnerRepoBranchesBranch function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoBranchesBranch === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing branch', (done) => {
        try {
          a.getReposOwnerRepoBranchesBranch('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'branch is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoBranchesBranch', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaborators - errors', () => {
      it('should have a getReposOwnerRepoCollaborators function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCollaborators === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCollaborators(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaborators', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCollaborators('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaborators', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should have a deleteReposOwnerRepoCollaboratorsUser function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoCollaboratorsUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing user', (done) => {
        try {
          a.deleteReposOwnerRepoCollaboratorsUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'user is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should have a getReposOwnerRepoCollaboratorsUser function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCollaboratorsUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing user', (done) => {
        try {
          a.getReposOwnerRepoCollaboratorsUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'user is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoCollaboratorsUser - errors', () => {
      it('should have a putReposOwnerRepoCollaboratorsUser function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoCollaboratorsUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing user', (done) => {
        try {
          a.putReposOwnerRepoCollaboratorsUser('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'user is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoCollaboratorsUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoComments - errors', () => {
      it('should have a getReposOwnerRepoComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoComments(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoComments('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoCommentsCommentId - errors', () => {
      it('should have a deleteReposOwnerRepoCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommentsCommentId - errors', () => {
      it('should have a getReposOwnerRepoCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoCommentsCommentId - errors', () => {
      it('should have a patchReposOwnerRepoCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoCommentsCommentId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommits - errors', () => {
      it('should have a getReposOwnerRepoCommits function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommits(null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommits('fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsRefStatus - errors', () => {
      it('should have a getReposOwnerRepoCommitsRefStatus function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsRefStatus === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoCommitsRefStatus('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsRefStatus', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCode - errors', () => {
      it('should have a getReposOwnerRepoCommitsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCommitsShaCodeComments - errors', () => {
      it('should have a getReposOwnerRepoCommitsShaCodeComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCommitsShaCodeComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoCommitsShaCodeComments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoCommitsShaCodeComments - errors', () => {
      it('should have a postReposOwnerRepoCommitsShaCodeComments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoCommitsShaCodeComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoCommitsShaCodeComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoCommitsShaCodeComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoCompareBaseIdHeadId - errors', () => {
      it('should have a getReposOwnerRepoCompareBaseIdHeadId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoCompareBaseIdHeadId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing baseId', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'baseId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing headId', (done) => {
        try {
          a.getReposOwnerRepoCompareBaseIdHeadId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'headId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoCompareBaseIdHeadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoContentsPath - errors', () => {
      it('should have a deleteReposOwnerRepoContentsPath function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoContentsPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.deleteReposOwnerRepoContentsPath('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoContentsPath - errors', () => {
      it('should have a getReposOwnerRepoContentsPath function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoContentsPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoContentsPath(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoContentsPath('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.getReposOwnerRepoContentsPath('fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoContentsPath - errors', () => {
      it('should have a putReposOwnerRepoContentsPath function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoContentsPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoContentsPath(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoContentsPath('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.putReposOwnerRepoContentsPath('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoContentsPath('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoContentsPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoContributors - errors', () => {
      it('should have a getReposOwnerRepoContributors function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoContributors === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoContributors(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoContributors('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing anon', (done) => {
        try {
          a.getReposOwnerRepoContributors('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'anon is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeployments - errors', () => {
      it('should have a getReposOwnerRepoDeployments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDeployments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDeployments(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDeployments('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoDeployments - errors', () => {
      it('should have a postReposOwnerRepoDeployments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoDeployments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoDeployments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoDeployments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoDeployments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeployments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDeploymentsIdStatuses - errors', () => {
      it('should have a getReposOwnerRepoDeploymentsIdStatuses function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDeploymentsIdStatuses === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoDeploymentsIdStatuses('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoDeploymentsIdStatuses - errors', () => {
      it('should have a postReposOwnerRepoDeploymentsIdStatuses function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoDeploymentsIdStatuses === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoDeploymentsIdStatuses('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoDeploymentsIdStatuses', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDownloads - errors', () => {
      it('should have a getReposOwnerRepoDownloads function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDownloads === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDownloads(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloads', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDownloads('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloads', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoDownloadsDownloadId - errors', () => {
      it('should have a deleteReposOwnerRepoDownloadsDownloadId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoDownloadsDownloadId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing downloadId', (done) => {
        try {
          a.deleteReposOwnerRepoDownloadsDownloadId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'downloadId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoDownloadsDownloadId - errors', () => {
      it('should have a getReposOwnerRepoDownloadsDownloadId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoDownloadsDownloadId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing downloadId', (done) => {
        try {
          a.getReposOwnerRepoDownloadsDownloadId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'downloadId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoDownloadsDownloadId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoEvents - errors', () => {
      it('should have a getReposOwnerRepoEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoEvents(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoEvents('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoForks - errors', () => {
      it('should have a getReposOwnerRepoForks function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoForks(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoForks('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoForks - errors', () => {
      it('should have a postReposOwnerRepoForks function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoForks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoForks(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoForks('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoForks('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoForks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitBlobs - errors', () => {
      it('should have a postReposOwnerRepoGitBlobs function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitBlobs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitBlobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitBlobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitBlobs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitBlobs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitBlobsShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitBlobsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitBlobsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitBlobsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitBlobsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitBlobsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitBlobsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitCommits - errors', () => {
      it('should have a postReposOwnerRepoGitCommits function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitCommits(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitCommits('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitCommits('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitCommitsShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitCommitsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitCommitsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitCommitsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitCommitsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitRefs - errors', () => {
      it('should have a getReposOwnerRepoGitRefs function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitRefs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitRefs(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitRefs('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitRefs - errors', () => {
      it('should have a postReposOwnerRepoGitRefs function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitRefs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitRefs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitRefs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitRefs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoGitRefsRef - errors', () => {
      it('should have a deleteReposOwnerRepoGitRefsRef function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoGitRefsRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.deleteReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitMatchingRefs - errors', () => {
      it('should have a getReposOwnerRepoGitMatchingRefs function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitMatchingRefs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitMatchingRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitMatchingRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoGitMatchingRefs('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitMatchingRefs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitRefsRef - errors', () => {
      it('should have a getReposOwnerRepoGitRefsRef function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitRefsRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoGitRefsRef - errors', () => {
      it('should have a patchReposOwnerRepoGitRefsRef function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoGitRefsRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoGitRefsRef('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoGitRefsRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitTags - errors', () => {
      it('should have a postReposOwnerRepoGitTags function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitTags === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitTags(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitTags('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitTags('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitTagsShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitTagsShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitTagsShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTagsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTagsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitTagsShaCode('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTagsShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoGitTrees - errors', () => {
      it('should have a postReposOwnerRepoGitTrees function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoGitTrees === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoGitTrees(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTrees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoGitTrees('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTrees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoGitTrees('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoGitTrees', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoGitTreesShaCode - errors', () => {
      it('should have a getReposOwnerRepoGitTreesShaCode function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoGitTreesShaCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTreesShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTreesShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing shaCode', (done) => {
        try {
          a.getReposOwnerRepoGitTreesShaCode('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'shaCode is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoGitTreesShaCode', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooks - errors', () => {
      it('should have a getReposOwnerRepoHooks function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoHooks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoHooks(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoHooks('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoHooks - errors', () => {
      it('should have a postReposOwnerRepoHooks function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoHooks === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoHooks(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoHooks('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoHooks('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooks', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoHooksHookId - errors', () => {
      it('should have a deleteReposOwnerRepoHooksHookId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoHooksHookId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.deleteReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoHooksHookId - errors', () => {
      it('should have a getReposOwnerRepoHooksHookId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoHooksHookId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.getReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoHooksHookId - errors', () => {
      it('should have a patchReposOwnerRepoHooksHookId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoHooksHookId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoHooksHookId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoHooksHookId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoHooksHookIdTests - errors', () => {
      it('should have a postReposOwnerRepoHooksHookIdTests function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoHooksHookIdTests === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooksHookIdTests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooksHookIdTests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing hookId', (done) => {
        try {
          a.postReposOwnerRepoHooksHookIdTests('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'hookId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoHooksHookIdTests', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssues - errors', () => {
      it('should have a getReposOwnerRepoIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssues(null, null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', null, null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing filter', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'filter is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing labels', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'labels is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sort', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'sort is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing direction', (done) => {
        try {
          a.getReposOwnerRepoIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'direction is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoIssues - errors', () => {
      it('should have a postReposOwnerRepoIssues function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoIssues(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoIssues('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoIssues('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesComments - errors', () => {
      it('should have a getReposOwnerRepoIssuesComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesComments(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesComments('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should have a deleteReposOwnerRepoIssuesCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoIssuesCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should have a getReposOwnerRepoIssuesCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoIssuesCommentsCommentId - errors', () => {
      it('should have a patchReposOwnerRepoIssuesCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoIssuesCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoIssuesCommentsCommentId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesEvents - errors', () => {
      it('should have a getReposOwnerRepoIssuesEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesEvents(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesEvents('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesEventsEventId - errors', () => {
      it('should have a getReposOwnerRepoIssuesEventsEventId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesEventsEventId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsEventId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsEventId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing eventId', (done) => {
        try {
          a.getReposOwnerRepoIssuesEventsEventId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'eventId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesEventsEventId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumber - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoIssuesNumber - errors', () => {
      it('should have a patchReposOwnerRepoIssuesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoIssuesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoIssuesNumber('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoIssuesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberComments - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberComments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoIssuesNumberComments - errors', () => {
      it('should have a postReposOwnerRepoIssuesNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoIssuesNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberEvents - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberEvents('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a deleteReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a getReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a postReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoIssuesNumberLabels - errors', () => {
      it('should have a putReposOwnerRepoIssuesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoIssuesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoIssuesNumberLabels('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoIssuesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoIssuesNumberLabelsName - errors', () => {
      it('should have a deleteReposOwnerRepoIssuesNumberLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoIssuesNumberLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.deleteReposOwnerRepoIssuesNumberLabelsName('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoIssuesNumberLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeys - errors', () => {
      it('should have a getReposOwnerRepoKeys function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoKeys(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoKeys('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoKeys - errors', () => {
      it('should have a postReposOwnerRepoKeys function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoKeys(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoKeys('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoKeys('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoKeysKeyId - errors', () => {
      it('should have a deleteReposOwnerRepoKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.deleteReposOwnerRepoKeysKeyId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoKeysKeyId - errors', () => {
      it('should have a getReposOwnerRepoKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.getReposOwnerRepoKeysKeyId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabels - errors', () => {
      it('should have a getReposOwnerRepoLabels function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLabels(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLabels('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoLabels - errors', () => {
      it('should have a postReposOwnerRepoLabels function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoLabelsName - errors', () => {
      it('should have a deleteReposOwnerRepoLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.deleteReposOwnerRepoLabelsName('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLabelsName - errors', () => {
      it('should have a getReposOwnerRepoLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLabelsName(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLabelsName('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.getReposOwnerRepoLabelsName('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoLabelsName - errors', () => {
      it('should have a patchReposOwnerRepoLabelsName function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoLabelsName === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing name', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'name is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoLabelsName('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoLabelsName', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoLanguages - errors', () => {
      it('should have a getReposOwnerRepoLanguages function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoLanguages === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoLanguages(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLanguages', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoLanguages('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoLanguages', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoMerges - errors', () => {
      it('should have a postReposOwnerRepoMerges function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoMerges === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoMerges(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMerges', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoMerges('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMerges', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoMerges('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMerges', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestones - errors', () => {
      it('should have a getReposOwnerRepoMilestones function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestones === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestones(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestones('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoMilestones - errors', () => {
      it('should have a postReposOwnerRepoMilestones function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoMilestones === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoMilestones(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoMilestones('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoMilestones('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoMilestones', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoMilestonesNumber - errors', () => {
      it('should have a deleteReposOwnerRepoMilestonesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoMilestonesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.deleteReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumber - errors', () => {
      it('should have a getReposOwnerRepoMilestonesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestonesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoMilestonesNumber - errors', () => {
      it('should have a patchReposOwnerRepoMilestonesNumber function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoMilestonesNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoMilestonesNumber('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoMilestonesNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoMilestonesNumberLabels - errors', () => {
      it('should have a getReposOwnerRepoMilestonesNumberLabels function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoMilestonesNumberLabels === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoMilestonesNumberLabels('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoMilestonesNumberLabels', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoNotifications - errors', () => {
      it('should have a getReposOwnerRepoNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoNotifications(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoNotifications('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoNotifications - errors', () => {
      it('should have a putReposOwnerRepoNotifications function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoNotifications === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoNotifications(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoNotifications('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoNotifications('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoNotifications', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPulls - errors', () => {
      it('should have a getReposOwnerRepoPulls function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPulls === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPulls(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPulls('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoPulls - errors', () => {
      it('should have a postReposOwnerRepoPulls function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoPulls === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoPulls(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoPulls('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoPulls('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPulls', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsComments - errors', () => {
      it('should have a getReposOwnerRepoPullsComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsComments(null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsComments('fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should have a deleteReposOwnerRepoPullsCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoPullsCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.deleteReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should have a getReposOwnerRepoPullsCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.getReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoPullsCommentsCommentId - errors', () => {
      it('should have a patchReposOwnerRepoPullsCommentsCommentId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoPullsCommentsCommentId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing commentId', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'commentId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoPullsCommentsCommentId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsCommentsCommentId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumber - errors', () => {
      it('should have a getReposOwnerRepoPullsNumber function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumber('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoPullsNumber - errors', () => {
      it('should have a patchReposOwnerRepoPullsNumber function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoPullsNumber === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoPullsNumber('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoPullsNumber', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberComments - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberComments('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoPullsNumberComments - errors', () => {
      it('should have a postReposOwnerRepoPullsNumberComments function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoPullsNumberComments === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoPullsNumberComments('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoPullsNumberComments', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberCommits - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberCommits function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberCommits === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberCommits('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberCommits', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberFiles - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberFiles function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberFiles === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFiles', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFiles', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberFiles('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberFiles', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoPullsNumberMerge - errors', () => {
      it('should have a getReposOwnerRepoPullsNumberMerge function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoPullsNumberMerge === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.getReposOwnerRepoPullsNumberMerge('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoPullsNumberMerge - errors', () => {
      it('should have a putReposOwnerRepoPullsNumberMerge function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoPullsNumberMerge === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing number', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'number is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoPullsNumberMerge('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoPullsNumberMerge', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReadme - errors', () => {
      it('should have a getReposOwnerRepoReadme function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReadme === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReadme(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReadme', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReadme('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReadme', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleases - errors', () => {
      it('should have a getReposOwnerRepoReleases function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleases === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleases(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleases('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoReleases - errors', () => {
      it('should have a postReposOwnerRepoReleases function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoReleases === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoReleases(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoReleases('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoReleases('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoReleases', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should have a deleteReposOwnerRepoReleasesAssetsId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoReleasesAssetsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should have a getReposOwnerRepoReleasesAssetsId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesAssetsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoReleasesAssetsId - errors', () => {
      it('should have a patchReposOwnerRepoReleasesAssetsId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoReleasesAssetsId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoReleasesAssetsId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesAssetsId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoReleasesId - errors', () => {
      it('should have a deleteReposOwnerRepoReleasesId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoReleasesId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.deleteReposOwnerRepoReleasesId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesId - errors', () => {
      it('should have a getReposOwnerRepoReleasesId function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesId(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesId('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoReleasesId('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchReposOwnerRepoReleasesId - errors', () => {
      it('should have a patchReposOwnerRepoReleasesId function', (done) => {
        try {
          assert.equal(true, typeof a.patchReposOwnerRepoReleasesId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchReposOwnerRepoReleasesId('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchReposOwnerRepoReleasesId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoReleasesIdAssets - errors', () => {
      it('should have a getReposOwnerRepoReleasesIdAssets function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoReleasesIdAssets === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesIdAssets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesIdAssets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing id', (done) => {
        try {
          a.getReposOwnerRepoReleasesIdAssets('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'id is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoReleasesIdAssets', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStargazers - errors', () => {
      it('should have a getReposOwnerRepoStargazers function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStargazers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStargazers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStargazers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStargazers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStargazers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsCodeFrequency - errors', () => {
      it('should have a getReposOwnerRepoStatsCodeFrequency function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsCodeFrequency === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsCodeFrequency(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCodeFrequency', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsCodeFrequency('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCodeFrequency', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsCommitActivity - errors', () => {
      it('should have a getReposOwnerRepoStatsCommitActivity function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsCommitActivity === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsCommitActivity(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCommitActivity', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsCommitActivity('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsCommitActivity', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsContributors - errors', () => {
      it('should have a getReposOwnerRepoStatsContributors function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsContributors === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsContributors(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsContributors('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsContributors', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsParticipation - errors', () => {
      it('should have a getReposOwnerRepoStatsParticipation function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsParticipation === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsParticipation(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsParticipation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsParticipation('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsParticipation', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatsPunchCard - errors', () => {
      it('should have a getReposOwnerRepoStatsPunchCard function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatsPunchCard === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatsPunchCard(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsPunchCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatsPunchCard('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatsPunchCard', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoStatusesRef - errors', () => {
      it('should have a getReposOwnerRepoStatusesRef function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoStatusesRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.getReposOwnerRepoStatusesRef('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postReposOwnerRepoStatusesRef - errors', () => {
      it('should have a postReposOwnerRepoStatusesRef function', (done) => {
        try {
          assert.equal(true, typeof a.postReposOwnerRepoStatusesRef === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing ref', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'ref is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postReposOwnerRepoStatusesRef('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postReposOwnerRepoStatusesRef', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscribers - errors', () => {
      it('should have a getReposOwnerRepoSubscribers function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoSubscribers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoSubscribers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscribers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoSubscribers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscribers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteReposOwnerRepoSubscription - errors', () => {
      it('should have a deleteReposOwnerRepoSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.deleteReposOwnerRepoSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteReposOwnerRepoSubscription(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteReposOwnerRepoSubscription('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoSubscription - errors', () => {
      it('should have a getReposOwnerRepoSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoSubscription(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoSubscription('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putReposOwnerRepoSubscription - errors', () => {
      it('should have a putReposOwnerRepoSubscription function', (done) => {
        try {
          assert.equal(true, typeof a.putReposOwnerRepoSubscription === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putReposOwnerRepoSubscription(null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putReposOwnerRepoSubscription('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.putReposOwnerRepoSubscription('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putReposOwnerRepoSubscription', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTags - errors', () => {
      it('should have a getReposOwnerRepoTags function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoTags === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoTags(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoTags('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTags', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoTeams - errors', () => {
      it('should have a getReposOwnerRepoTeams function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoTeams(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoTeams('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoTeams', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoWatchers - errors', () => {
      it('should have a getReposOwnerRepoWatchers function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoWatchers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoWatchers(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoWatchers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoWatchers('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoWatchers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getReposOwnerRepoArchiveFormatPath - errors', () => {
      it('should have a getReposOwnerRepoArchiveFormatPath function', (done) => {
        try {
          assert.equal(true, typeof a.getReposOwnerRepoArchiveFormatPath === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath(null, null, null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath('fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing archiveFormat', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath('fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'archiveFormat is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing pathParam', (done) => {
        try {
          a.getReposOwnerRepoArchiveFormatPath('fakeparam', 'fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'pathParam is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getReposOwnerRepoArchiveFormatPath', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getRepositories - errors', () => {
      it('should have a getRepositories function', (done) => {
        try {
          assert.equal(true, typeof a.getRepositories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchCode - errors', () => {
      it('should have a getSearchCode function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchCode === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchCode('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchCodeWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    const fakeData = {
      order: 'desc'
    };
    describe('#getSearchCodeWithOptions - errors', () => {
      it('should have a getSearchCodeWithOptions function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchCodeWithOptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchCodeWithOptions(fakeData, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchCodeWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchIssues - errors', () => {
      it('should have a getSearchIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchIssues('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchIssuesWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchIssuesWithOptions - errors', () => {
      it('should have a getSearchIssuesWithOptions function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchIssuesWithOptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchIssuesWithOptions(fakeData, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchIssuesWithOptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchRepositories - errors', () => {
      it('should have a getSearchRepositories function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchRepositories === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchRepositories('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchRepositories', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getSearchUsers - errors', () => {
      it('should have a getSearchUsers function', (done) => {
        try {
          assert.equal(true, typeof a.getSearchUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing q', (done) => {
        try {
          a.getSearchUsers('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'q is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getSearchUsers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamId - errors', () => {
      it('should have a deleteTeamsTeamId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamId(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamId - errors', () => {
      it('should have a getTeamsTeamId function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamId(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchTeamsTeamId - errors', () => {
      it('should have a patchTeamsTeamId function', (done) => {
        try {
          assert.equal(true, typeof a.patchTeamsTeamId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.patchTeamsTeamId(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchTeamsTeamId('fakeparam', null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchTeamsTeamId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembers - errors', () => {
      it('should have a getTeamsTeamIdMembers function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembers(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdMembersUsername - errors', () => {
      it('should have a deleteTeamsTeamIdMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamIdMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamIdMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteTeamsTeamIdMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembersUsername - errors', () => {
      it('should have a getTeamsTeamIdMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getTeamsTeamIdMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdMembersUsername - errors', () => {
      it('should have a putTeamsTeamIdMembersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putTeamsTeamIdMembersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.putTeamsTeamIdMembersUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putTeamsTeamIdMembersUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdMembershipsUsername - errors', () => {
      it('should have a deleteTeamsTeamIdMembershipsUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamIdMembershipsUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamIdMembershipsUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteTeamsTeamIdMembershipsUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdMembershipsUsername - errors', () => {
      it('should have a getTeamsTeamIdMembershipsUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdMembershipsUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdMembershipsUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getTeamsTeamIdMembershipsUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdMembershipsUsername - errors', () => {
      it('should have a putTeamsTeamIdMembershipsUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putTeamsTeamIdMembershipsUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.putTeamsTeamIdMembershipsUsername(null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putTeamsTeamIdMembershipsUsername('fakeparam', null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdMembershipsUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdRepos - errors', () => {
      it('should have a getTeamsTeamIdRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdRepos(null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should have a deleteTeamsTeamIdReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteTeamsTeamIdReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteTeamsTeamIdReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should have a getTeamsTeamIdReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getTeamsTeamIdReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getTeamsTeamIdReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putTeamsTeamIdReposOwnerRepo - errors', () => {
      it('should have a putTeamsTeamIdReposOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.putTeamsTeamIdReposOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing teamId', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo(null, null, null, (data, error) => {
            try {
              const displayE = 'teamId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo('fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putTeamsTeamIdReposOwnerRepo('fakeparam', 'fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putTeamsTeamIdReposOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUser - errors', () => {
      it('should have a getUser function', (done) => {
        try {
          assert.equal(true, typeof a.getUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#patchUser - errors', () => {
      it('should have a patchUser function', (done) => {
        try {
          assert.equal(true, typeof a.patchUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.patchUser(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-patchUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserEmails - errors', () => {
      it('should have a deleteUserEmails function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserEmails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.deleteUserEmails(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserEmails', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserEmails - errors', () => {
      it('should have a getUserEmails function', (done) => {
        try {
          assert.equal(true, typeof a.getUserEmails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postUserEmails - errors', () => {
      it('should have a postUserEmails function', (done) => {
        try {
          assert.equal(true, typeof a.postUserEmails === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postUserEmails(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postUserEmails', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowers - errors', () => {
      it('should have a getUserFollowers function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowing - errors', () => {
      it('should have a getUserFollowing function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowing === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserFollowingUsername - errors', () => {
      it('should have a deleteUserFollowingUsername function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserFollowingUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.deleteUserFollowingUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserFollowingUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserFollowingUsername - errors', () => {
      it('should have a getUserFollowingUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getUserFollowingUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUserFollowingUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserFollowingUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserFollowingUsername - errors', () => {
      it('should have a putUserFollowingUsername function', (done) => {
        try {
          assert.equal(true, typeof a.putUserFollowingUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.putUserFollowingUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserFollowingUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserIssues - errors', () => {
      it('should have a getUserIssues function', (done) => {
        try {
          assert.equal(true, typeof a.getUserIssues === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing filter', (done) => {
        try {
          a.getUserIssues(null, null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'filter is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing state', (done) => {
        try {
          a.getUserIssues('fakeparam', null, null, null, null, null, (data, error) => {
            try {
              const displayE = 'state is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing labels', (done) => {
        try {
          a.getUserIssues('fakeparam', 'fakeparam', null, null, null, null, (data, error) => {
            try {
              const displayE = 'labels is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing sort', (done) => {
        try {
          a.getUserIssues('fakeparam', 'fakeparam', 'fakeparam', null, null, null, (data, error) => {
            try {
              const displayE = 'sort is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing direction', (done) => {
        try {
          a.getUserIssues('fakeparam', 'fakeparam', 'fakeparam', 'fakeparam', null, null, (data, error) => {
            try {
              const displayE = 'direction is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserIssues', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeys - errors', () => {
      it('should have a getUserKeys function', (done) => {
        try {
          assert.equal(true, typeof a.getUserKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postUserKeys - errors', () => {
      it('should have a postUserKeys function', (done) => {
        try {
          assert.equal(true, typeof a.postUserKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postUserKeys(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postUserKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserKeysKeyId - errors', () => {
      it('should have a deleteUserKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.deleteUserKeysKeyId(null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserKeysKeyId - errors', () => {
      it('should have a getUserKeysKeyId function', (done) => {
        try {
          assert.equal(true, typeof a.getUserKeysKeyId === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing keyId', (done) => {
        try {
          a.getUserKeysKeyId(null, (data, error) => {
            try {
              const displayE = 'keyId is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserKeysKeyId', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserOrgs - errors', () => {
      it('should have a getUserOrgs function', (done) => {
        try {
          assert.equal(true, typeof a.getUserOrgs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserRepos - errors', () => {
      it('should have a getUserRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getUserRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#postUserRepos - errors', () => {
      it('should have a postUserRepos function', (done) => {
        try {
          assert.equal(true, typeof a.postUserRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing body', (done) => {
        try {
          a.postUserRepos(null, (data, error) => {
            try {
              const displayE = 'body is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-postUserRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarred - errors', () => {
      it('should have a getUserStarred function', (done) => {
        try {
          assert.equal(true, typeof a.getUserStarred === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserStarredOwnerRepo - errors', () => {
      it('should have a deleteUserStarredOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserStarredOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteUserStarredOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteUserStarredOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserStarredOwnerRepo - errors', () => {
      it('should have a getUserStarredOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getUserStarredOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getUserStarredOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getUserStarredOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserStarredOwnerRepo - errors', () => {
      it('should have a putUserStarredOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.putUserStarredOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putUserStarredOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putUserStarredOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserStarredOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptions - errors', () => {
      it('should have a getUserSubscriptions function', (done) => {
        try {
          assert.equal(true, typeof a.getUserSubscriptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#deleteUserSubscriptionsOwnerRepo - errors', () => {
      it('should have a deleteUserSubscriptionsOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.deleteUserSubscriptionsOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.deleteUserSubscriptionsOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.deleteUserSubscriptionsOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-deleteUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserSubscriptionsOwnerRepo - errors', () => {
      it('should have a getUserSubscriptionsOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.getUserSubscriptionsOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.getUserSubscriptionsOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.getUserSubscriptionsOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#putUserSubscriptionsOwnerRepo - errors', () => {
      it('should have a putUserSubscriptionsOwnerRepo function', (done) => {
        try {
          assert.equal(true, typeof a.putUserSubscriptionsOwnerRepo === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing owner', (done) => {
        try {
          a.putUserSubscriptionsOwnerRepo(null, null, (data, error) => {
            try {
              const displayE = 'owner is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing repo', (done) => {
        try {
          a.putUserSubscriptionsOwnerRepo('fakeparam', null, (data, error) => {
            try {
              const displayE = 'repo is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-putUserSubscriptionsOwnerRepo', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUserTeams - errors', () => {
      it('should have a getUserTeams function', (done) => {
        try {
          assert.equal(true, typeof a.getUserTeams === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsers - errors', () => {
      it('should have a getUsers function', (done) => {
        try {
          assert.equal(true, typeof a.getUsers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsername - errors', () => {
      it('should have a getUsersUsername function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsername === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsername(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsername', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEvents - errors', () => {
      it('should have a getUsersUsernameEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameEvents(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameEventsOrgsOrg - errors', () => {
      it('should have a getUsersUsernameEventsOrgsOrg function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameEventsOrgsOrg === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrg(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing org', (done) => {
        try {
          a.getUsersUsernameEventsOrgsOrg('fakeparam', null, (data, error) => {
            try {
              const displayE = 'org is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameEventsOrgsOrg', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameFollowers - errors', () => {
      it('should have a getUsersUsernameFollowers function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameFollowers === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameFollowers(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowers', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameFollowingTargetUser - errors', () => {
      it('should have a getUsersUsernameFollowingTargetUser function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameFollowingTargetUser === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameFollowingTargetUser(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowingTargetUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing targetUser', (done) => {
        try {
          a.getUsersUsernameFollowingTargetUser('fakeparam', null, (data, error) => {
            try {
              const displayE = 'targetUser is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameFollowingTargetUser', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameGists - errors', () => {
      it('should have a getUsersUsernameGists function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameGists === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameGists(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameGists', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameKeys - errors', () => {
      it('should have a getUsersUsernameKeys function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameKeys === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameKeys(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameKeys', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameOrgs - errors', () => {
      it('should have a getUsersUsernameOrgs function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameOrgs === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameOrgs(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameOrgs', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEvents - errors', () => {
      it('should have a getUsersUsernameReceivedEvents function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReceivedEvents === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReceivedEvents(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReceivedEvents', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameReceivedEventsPublic - errors', () => {
      it('should have a getUsersUsernameReceivedEventsPublic function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameReceivedEventsPublic === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameReceivedEventsPublic(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameReceivedEventsPublic', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameRepos - errors', () => {
      it('should have a getUsersUsernameRepos function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameRepos === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameRepos(null, null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameRepos', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameStarred - errors', () => {
      it('should have a getUsersUsernameStarred function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameStarred === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameStarred(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameStarred', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });

    describe('#getUsersUsernameSubscriptions - errors', () => {
      it('should have a getUsersUsernameSubscriptions function', (done) => {
        try {
          assert.equal(true, typeof a.getUsersUsernameSubscriptions === 'function');
          done();
        } catch (error) {
          log.error(`Test Failure: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
      it('should error if - missing username', (done) => {
        try {
          a.getUsersUsernameSubscriptions(null, (data, error) => {
            try {
              const displayE = 'username is required';
              runErrorAsserts(data, error, 'AD.300', 'Test-github-adapter-getUsersUsernameSubscriptions', displayE);
              done();
            } catch (err) {
              log.error(`Test Failure: ${err}`);
              done(err);
            }
          });
        } catch (error) {
          log.error(`Adapter Exception: ${error}`);
          done(error);
        }
      }).timeout(attemptTimeout);
    });
  });
});
